#!/usr/bin/env python3
# -*- coding: utf-8 -*-
#
# License: GNU General Public License v2
#
# Author: thl-cmk[at]outlook[dot]com
# URL   : https://thl-cmk.hopto.org
# Date  : 2021-08-11
#
# Check Point Internal CA metrics plugin
#

from cmk.gui.i18n import _

from cmk.gui.plugins.metrics import (
    metric_info,
    graph_info,
    perfometer_info,
)

metric_info['checkpoint_ica_icavalidcertificates'] = {
    'title': _('Valid certificates'),
    'unit': 'count',
    'color': '16/a',
}
metric_info['checkpoint_ica_icatotalnumberofcertificates'] = {
    'title': _('Total certificates'),
    'unit': 'count',
    'color': '26/a',
}
metric_info['checkpoint_ica_icapendingcertificates'] = {
    'title': _('Pending certificates'),
    'unit': 'count',
    'color': '11/a',
}
metric_info['checkpoint_ica_icarevokedcertificates'] = {
    'title': _('Revoked certificates'),
    'unit': 'count',
    'color': '21/a',
}
metric_info['checkpoint_ica_icatotalcertificatesofusers'] = {
    'title': _('Certificates of users'),
    'unit': 'count',
    'color': '31/a',
}

metric_info['checkpoint_ica_icacertificatesofldapusers'] = {
    'title': _('Certificates of LDAP users'),
    'unit': 'count',
    'color': '41/a',
}
metric_info['checkpoint_ica_icacertificatesofinternalusers'] = {
    'title': _('Certificates of internal users'),
    'unit': 'count',
    'color': '12/a',
}
metric_info['checkpoint_ica_icatotalnumberofsiccertificates'] = {
    'title': _('SIC certificates'),
    'unit': 'count',
    'color': '22/a',
}
metric_info['checkpoint_ica_icatotalnumberofikecertificates'] = {
    'title': _('IKE certificates'),
    'unit': 'count',
    'color': '32/a',
}
metric_info['checkpoint_ica_icarenewedcertificates'] = {
    'title': _('Renewed Certificates'),
    'unit': 'count',
    'color': '42/a',
}
metric_info['checkpoint_ica_icaexpieredcertificates'] = {
    'title': _('Expired Certificates'),
    'unit': 'count',
    'color': '13/a',
}
metric_info['checkpoint_ica_icaLastCrlDistributionPoint'] = {
    'title': _('Last Crl Distribution Point'),
    'unit': 'count',
    'color': '23/a',
}

graph_info['checkpoint_ica_topology_table_routes'] = {
    'title': _('Routes by origin type'),
    'metrics': [
        ('checkpoint_ica_icatotalnumberofcertificates', 'line'),
        ('checkpoint_ica_icavalidcertificates', 'line'),
        ('checkpoint_ica_icapendingcertificates', 'line'),
        ('checkpoint_ica_icarevokedcertificates', 'line'),
        ('checkpoint_ica_icatotalcertificatesofusers', 'line'),
        ('checkpoint_ica_icacertificatesofldapusers', 'line'),
        ('checkpoint_ica_icacertificatesofinternalusers', 'line'),
        ('checkpoint_ica_icatotalnumberofsiccertificates', 'line'),
        ('checkpoint_ica_icatotalnumberofikecertificates', 'line'),
        ('checkpoint_ica_icarenewedcertificates', 'line'),
        ('checkpoint_ica_icaexpieredcertificates', 'line'),
        ('checkpoint_ica_icaLastCrlDistributionPoint', 'line'),

    ],
    'range': (0, 'checkpoint_ica_icatotalnumberofcertificates:max')
}

perfometer_info.append(('stacked', [
    {
        'type': 'logarithmic',
        'metric': 'checkpoint_ica_icatotalnumberofcertificates',
        'half_value': 500.0,
        'exponent': 2,
    },
    {
        'type': 'logarithmic',
        'metric': 'checkpoint_ica_icavalidcertificates',
        'half_value': 500.0,
        'exponent': 2,
    }
]))

